aboutsummaryrefslogtreecommitdiff
path: root/tw/system/vin.scm
diff options
context:
space:
mode:
Diffstat (limited to 'tw/system/vin.scm')
-rw-r--r--tw/system/vin.scm30
1 files changed, 15 insertions, 15 deletions
diff --git a/tw/system/vin.scm b/tw/system/vin.scm
index c3cbc50c..4d6b216f 100644
--- a/tw/system/vin.scm
+++ b/tw/system/vin.scm
@@ -208,32 +208,32 @@
(syncthing-configuration (user "timo")))
(service postgresql-service-type
(postgresql-configuration
- ;; hledger-dashboard is linked against libpq from postgresql@14.
- ;; Using a different Postgres server version is probably fine, though.
- (postgresql postgresql-14)))
- (simple-service 'hledger-dashboard-roles postgresql-role-service-type
+ (postgresql postgresql-15)))
+ (simple-service 'ledgerplot-roles postgresql-role-service-type
(list (postgresql-role
(name "timo")
(create-database? #t)
(permissions '(login)))))
- (simple-service 'hledger-dashboard shepherd-root-service-type
+ (simple-service 'ledgerplot shepherd-root-service-type
(list (shepherd-service
- (provision '(hledger-dashboard))
+ (provision '(ledgerplot))
(requirement '(postgresql syncthing-timo))
(documentation
"Monitor a ledger file and keep a database in sync with it.")
(start #~(make-forkexec-constructor
- (list #$(file-append hledger-dashboard "/bin/hledger-dashboard")
- ;; This is where Syncthing puts the ledger file.
- "-f" "/home/timo/sync/ledger/ledger.journal")
+ (list #$(file-append ledgerplot "/bin/ledgerplot")
+ "-wd" "timo")
#:user "timo" #:group "users"
#:environment-variables
- ;; Use an appropriate locale so that hledger-dashboard
- ;; can read the UTF-8 ledger file.
- (cons* (string-append
- "LC_ALL=" #$(locale-definition-name
- (car locale-definitions)))
- (default-environment-variables))))
+ (cons*
+ ;; This is where Syncthing puts the ledger file.
+ "LEDGER_FILE=/home/timo/sync/ledger/ledger.journal"
+ ;; Use an appropriate locale so that ledgerplot
+ ;; can read the UTF-8 ledger file.
+ (string-append
+ "LC_ALL=" #$(locale-definition-name
+ (car locale-definitions)))
+ (default-environment-variables))))
(stop #~(make-kill-destructor)))))
(service unattended-upgrade-service-type